@@ -32,6 +32,7 @@
   #:use-module (oauth request)
   #:use-module (ice-9 receive)
   #:use-module (rnrs bytevectors)
+  #:use-module (web client)
   #:use-module (web uri)
   #:export (oauth1-client-request-token
             oauth1-client-authorization-url
@@ -44,14 +45,16 @@
                                       (method 'POST)
                                       (params '())
                                       (params-location 'header)
-                                      (signature oauth1-signature-hmac-sha1))
+                                      (signature oauth1-signature-hmac-sha1)
+                                      (http-proc http-request))
   "Obtain a request token from the server @var{url} for the given client
 @var{credentials}. Takes one optional argument, @var{callback}, to set the
 callback URL that the server will redirect after authorization is completed, it
 defaults to 'oob' (no redirection is performed). An HTTP method can be selected
 with @var{method} and additional parameters can be given in @var{params}. The
 @{params-location} can be the Authorization 'header (default), the 'query or the
-'body."
+'body. Finally, an @var{http-proc} procedure can be specified to provide an HTTP
+request implementation (defaults to (http-request))."
   (let ((response (make-oauth1-response "" "" '()))
         (request (make-oauth-request url method params)))
     (oauth1-request-add-default-params request)
@@ -61,7 +64,9 @@ with @var{method} and additional parameters can be given in @var{params}. The
                              (oauth1-credentials-key credentials))
     (oauth1-request-sign request credentials response #:signature signature)
     (receive (response body)
-        (oauth1-http-request request #:params-location params-location)
+        (oauth1-http-request request
+                             #:params-location params-location
+                             #:http-proc http-proc)
       (oauth1-http-body->response response body))))
 
 (define* (oauth1-client-authorization-url url
@@ -83,13 +88,16 @@ browser."
                                      (method 'POST)
                                      (extra-headers '())
                                      (params-location 'header)
-                                     (signature oauth1-signature-hmac-sha1))
+                                     (signature oauth1-signature-hmac-sha1)
+                                     (http-proc http-request))
   "Obtain an access token from the server @var{url} for the given client
 @var{credentials} (key and secret), request token @var{response} and
 @var{verifier}. Access tokens are used to connect to protected resources. An
 HTTP method can be selected with @var{method} and additional @var{extra-headers}
 can be provided. The @{params-location} can be the Authorization
-'header (default), the 'query or the 'body."
+'header (default), the 'query or the 'body. Finally, an @var{http-proc}
+procedure can be specified to provide an HTTP request implementation (defaults
+to (http-request))."
   (let ((request (make-oauth-request url method '())))
     (oauth1-request-add-default-params request)
     (oauth-request-add-param request
@@ -103,7 +111,8 @@ can be provided. The @{params-location} can be the Authorization
     (receive (response body)
         (oauth1-http-request request
                              #:params-location params-location
-                             #:extra-headers extra-headers)
+                             #:extra-headers extra-headers
+                             #:http-proc http-proc)
       (oauth1-http-body->response response body))))
 
 (define* (oauth1-client-http-request url credentials response
@@ -113,7 +122,8 @@ can be provided. The @{params-location} can be the Authorization
                                      (params '())
                                      (params-location 'header)
                                      (extra-headers '())
-                                     (signature oauth1-signature-hmac-sha1))
+                                     (signature oauth1-signature-hmac-sha1)
+                                     (http-proc http-request))
   "Access a server's protected resource @var{url} with the given client
 @var{credentials} and an access token @var{response}. Returns two values, the
 response and the body as a string. An HTTP method can be selected with
@@ -121,7 +131,9 @@ response and the body as a string. An HTTP method can be selected with
 parameters can be given in @var{params} as an alist and a list of
 @var{extra-headers} can be provided as well. The @{params-location} can be the
 Authorization 'header (default), the 'query or the 'body. Also, an optional
-@var{signature} algorithm can be specified."
+@var{signature} algorithm can be specified. Finally, an @var{http-proc}
+procedure can be specified to provide an HTTP request implementation (defaults
+to (http-request))."
   (let ((request (make-oauth-request url method params)))
     (oauth1-request-add-default-params request)
     (oauth-request-add-param request
@@ -135,7 +147,8 @@ Authorization 'header (default), the 'query or the 'body. Also, an optional
         (oauth1-http-request request
                              #:params-location params-location
                              #:extra-headers extra-headers
-                             #:body body)
+                             #:body body
+                             #:http-proc http-proc)
       (values response (if (string? resp-body) resp-body (utf8->string resp-body))))))
 
 ;;; (oauth oauth1 client) ends here
